<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * MP3 Clips Amazon Widget
 *
 * This file contains the class Widget_Amazon_MP3Clips
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate.Widget.Amazon
 */

/**
 * Widget_Amazon_MP3Clips is the implemenation of the Amaozn MP3 Clips Widget
 * as a WordPress Widget
 *
 * @package com.mdbitz.wordpress.amazon_associate.Widget.Amazon
 */
class Widget_Amazon_MP3Clips extends Widget_MDBitz_Base {

    /**
     * constructor
     */
    function Widget_Amazon_MP3Clips() {

        /* Widget Settings */
        $widget_settings = array( 'classname'=>'Widget_Amazon_MP3Clips', 'description'=>'Amazon MP3 Clips Widget' );

        /* Widget Control Options */
        $widget_options = array ( 'width' => 250, 'height' => 600, 'id_base' => 'amazon-mp3-clips-widget' );

        parent::WP_Widget('amazon-mp3-clips-widget', 'Amazon MP3 Clips Widget', $widget_settings, $widget_options);
    }

    /**
     * @see WP_Widget::widget
     */
    function widget($args, $instance) {
        global $wpaa;
        echo $before_widget;
        $title = apply_filters('widget_title', $instance['widgetTitle']);
        if ( $title ) {
            echo $before_title . $title . $after_title;
        }
        $instance['tag'] = $wpaa->getAssociateId();
        AmazonWidget::MP3Clips( $instance );
        echo $after_widget;
    }

    /**
     * @see WP_Widget::update
     */
    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['width'] = strip_tags($new_instance['width']);
        $instance['height'] = strip_tags($new_instance['height']);
        $instance['widgetTitle'] = strip_tags($new_instance['widgetTitle']);
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['widgetType'] = strip_tags($new_instance['widgetType']);
        $instance['browseNode'] = strip_tags($new_instance['browseNode']);
        $instance['ASIN'] = strip_tags($new_instance['ASIN']);
        $instance['keywords'] = strip_tags($new_instance['keywords']);
        if( isset( $new_instance['shuffleTracks'] ) ) {
            $instance['shuffleTracks'] = "True";
        } else {
            $instance['shuffleTracks'] = "False";
        }
        $instance['maxResults'] = strip_tags($new_instance['maxResults']);
        $instance['marketPlace'] = strip_tags($new_instance['marketPlace']);
        return $instance;
    }

    /**
     * @see WP_Widget::form
     */
    function form($instance) {
        $instance = wp_parse_args( (array) $instance, AmazonWidget_MP3Clips::getDefaultOptions() );
        $width = esc_attr($instance['width']);
        $height = esc_attr($instance['height']);
        $widgetTitle = esc_attr($instance['widgetTitle']);
        $title = esc_attr($instance['title']);
        $widgetType = esc_attr($instance['widgetType']);
        $browseNode = esc_attr($instance['browseNode']);
        $ASIN = esc_attr($instance['ASIN']);
        $keywords = esc_attr($instance['keywords']);
        $shuffleTracks = false;
        if( $instance['shuffleTracks'] == "True" ) {
            $shuffleTracks = true;
        }
        $maxResults = esc_attr($instance['maxResults']);
        $marketPlace = esc_attr($instance['marketPlace']);
        ?>
<div>
    <h3>Basic Properties</h3>
        <?php
        echo $this->textinputWithLabel( "Widget Title:", 'widgetTitle', $widgetTitle );
        echo $this->textinputWithLabel( 'Width:', 'width', $width );
        echo $this->textinputWithLabel( 'Height:', 'height', $height );
        echo $this->selectWithLabel( 'Market Place:', 'marketPlace', AmazonWidget_Abstract::getAvailableMarkets(), $marketPlace );
        ?>
    <h3>Widget Options</h3>
        <?php
        echo $this->textinputWithLabel( 'Title:', 'title', $title );
        $js = "onchange=\" changeAmazonWidgetMP3Clips( '" . $this->get_field_id('widgetType') . "', '" . $this->get_field_id('ASIN') . "', '" . $this->get_field_id('keywords') . "', '" . $this->get_field_id('browseNode') . "' )\"";
        echo $this->selectWithLabel( 'Widget Type', 'widgetType', AmazonWidget_Carousel::getAvailableTypes(), $widgetType, $js );
        echo $this->textinputWithLabel( "Browse Node:", 'browseNode', $browseNode );
        echo $this->textinputWithlabel( "ASIN:", 'ASIN', $ASIN );
        echo $this->textinputWithlabel( "Keywords:", 'keywords', $keywords );
        echo $this->checkboxWithLabel( "Shuffle Tracks:", 'shuffleTracks', $shuffleTracks );
        echo $this->textinputWithlabel( "Max Results:", 'maxResults', $maxResults );
        ?>
</div>
<script type="text/javascript">
    if( window.changeAmazonWidgetMP3Clips ) {

    } else {
        function changeAmazonWidgetMP3Clips( id, asin_id, keywords_id, node_id ) {
            var value = jQuery( "#" + id ).val();
            if( value == "ASINList" ) {
                jQuery( "#" + asin_id ).removeAttr('disabled');
                jQuery( "#" + keywords_id ).attr('disabled','disabled');
                jQuery( "#" + node_id ).attr('disabled','disabled');
            } else if ( value == "SearchAndAdd" ) {
                jQuery( "#" + asin_id ).attr('disabled','disabled');
                jQuery( "#" + keywords_id ).removeAttr('disabled');
                jQuery( "#" + node_id ).removeAttr('disabled');
            } else {
                jQuery( "#" + asin_id ).attr('disabled','disabled');
                jQuery( "#" + keywords_id ).attr('disabled','disabled');
                jQuery( "#" + node_id ).removeAttr('disabled');
            }
        }
    }
    jQuery( "#<?php echo $this->get_field_id('widgetType');?>" ).change();
</script>
        <?php
    }

} // class Widget_Amazon_MP3Clips